package edu.travel.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.adapter.service.order.OrderAdapter;
import edu.travel.remote.dto.AddOrderDto;
import edu.travel.remote.dto.GetOrderItemInfoByOrderNumDto;
import edu.travel.remote.dto.ShowOrderInfoDto;
import edu.travel.remote.vo.OrderItemVo;
import edu.travel.remote.vo.ShopOrderVo;
import edu.travel.remote.vo.ShowOrderInfoVo;
import edu.travel.rpc.RPCBaseResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;


/**
 * 类功能描述：
 *  商城订单
 * @author 大春
 * @date 2025/03/19
 */

@RestController
@RequestMapping("/shopOrder")
public class ShopOrderController {
    @Autowired
    private OrderAdapter orderAdapter;
    /**
     * 状态查询我的订单
     *
     * @param params
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShowOrderInfoVo }>>
     */
    @GetMapping("/showOrderInfo")
    public RPCBaseResponse<Page<ShowOrderInfoVo>> showOrderInfo(ShowOrderInfoDto params) {
        return orderAdapter.showOrderInfo(params);
    }

    /**
     * 下单生成订单
     *
     * @return {@link RPCBaseResponse }<{@link Void }>
     */
    @PostMapping("/addShopOrder")
    public RPCBaseResponse<Void> addShopOrder(@RequestBody AddOrderDto params) {
        return orderAdapter.addShopOrder(params);
    }

    /**
     * 查询订单下的商品快照
     *
     * @param params 订单号
     * @return {@link RPCBaseResponse }<{@link String }>
     */

    @GetMapping("/getOrderItemInfo")
    public RPCBaseResponse<Page<OrderItemVo>> getOrderItemInfo(GetOrderItemInfoByOrderNumDto params) {
        return orderAdapter.getOrderItemInfo(params);
    }

    /**
     * 通过订单号查询订单详情
     *
     * @param orderNum 订单号
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShowOrderInfoVo }>>
     */
    @GetMapping("/orderInfoByOrderNum")
    public RPCBaseResponse<ShowOrderInfoVo> orderInfoByOrderNum(String orderNum) {
        return orderAdapter.orderInfoByOrderNum(orderNum);
    }

    /**
     * 修改订单状态
     *
     * @param orderNum 订单号 state 状态 OrderStateEnum
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShowOrderInfoVo }>>
     */
    @GetMapping("/changeOrderState")
    public RPCBaseResponse<Void> changeOrderState(String orderNum, String state) {
        return orderAdapter.changeOrderState(orderNum, state);
    }

    /**
     * 订单号查询订单
     *
     * @param id
     * @return {@link RPCBaseResponse }<{@link ShopOrderVo }>
     */

    @GetMapping("/getFormId")
    public RPCBaseResponse<ShopOrderVo> getFormId(@RequestParam("id") String id) {
        return orderAdapter.getFormId(id);
    }
}
