package edu.travel.commodity.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.commodity.entity.ShopSpec;
import edu.travel.commodity.mapper.ShopSpecMapper;
import edu.travel.commodity.service.ShopSpecService;
import edu.travel.commodity.utils.PageUtil;
import edu.travel.remote.dto.SpecDto;
import edu.travel.remote.vo.ProductSpecInsertShopSpecVo;
import edu.travel.remote.vo.SpecVo;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.service.SysServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ShopSpecServiceImpl extends SysServiceImpl<ShopSpecMapper, ShopSpec> implements ShopSpecService {


    @Override
    public Page<SpecVo> getShopSpec(Long countryId, Integer currentPage, Integer pageSize) {
        LambdaQueryWrapper<ShopSpec> query = Wrappers.<ShopSpec>lambdaQuery()
                .eq(ShopSpec::getCountryId, countryId).orderByDesc(ShopSpec::getCreateTime);
        Page<ShopSpec> page = this.page(new Page<>(currentPage, pageSize), query);
        return PageUtil.toPageEntity(page, SpecVo.class);
    }

    @Override
    public RPCBaseResponse<ProductSpecInsertShopSpecVo> insertOrUpdate(SpecDto specDto) {
        // 获取现有的 ShopSpec 对象
        ShopSpec spec = getById(specDto.getSpecId());

        // 如果规格不存在，则执行新增逻辑
        if (ObjectUtil.isEmpty(spec)) {
            // 构建查询条件，检查是否有相同的规格名称
            LambdaQueryWrapper<ShopSpec> query = Wrappers.<ShopSpec>lambdaQuery()
                    .eq(ShopSpec::getSpecName, specDto.getSpecName())
                    .eq(ShopSpec::getCountryId, specDto.getCountryId());

            // 查询是否存在同名规格
            ShopSpec existingSpec = getOne(query);
            if (existingSpec != null) {
                // 如果存在同名规格，返回其名称和 ID
                ProductSpecInsertShopSpecVo responseVo = new ProductSpecInsertShopSpecVo();
                responseVo.setSpecName(existingSpec.getSpecName());
                responseVo.setId(String.valueOf(existingSpec.getId()));
                return new RPCBaseResponse<>(200, "规格名称已存在", responseVo);
            }

            // 如果不存在同名规格，则新增
            ShopSpec newSpec = BeanUtil.toBean(specDto, ShopSpec.class);
            save(newSpec);

            // 返回新增规格的名称和 ID
            ProductSpecInsertShopSpecVo responseVo = new ProductSpecInsertShopSpecVo();
            responseVo.setSpecName(newSpec.getSpecName());
            responseVo.setId(String.valueOf(newSpec.getId()));
            return new RPCBaseResponse<>(201, "新增成功", responseVo);
        }

        // 如果规格已存在，更新名称
        spec.setSpecName(specDto.getSpecName());
        updateById(spec);

        // 返回更新后的规格名称和 ID
        ProductSpecInsertShopSpecVo responseVo = new ProductSpecInsertShopSpecVo();
        responseVo.setSpecName(spec.getSpecName());
        responseVo.setId(String.valueOf(spec.getId()));
        return new RPCBaseResponse<>(200, "更新成功", responseVo);
    }


    /**
     * 获取规格名称（模糊查询）
     * @param specName
     * @return
     */
    @Override
    public RPCBaseResponse<List<SpecVo>> getSpecName(String specName) {
        // 模糊查询规格
        LambdaQueryWrapper<ShopSpec> query = Wrappers.<ShopSpec>lambdaQuery()
                .like(ShopSpec::getSpecName, specName);
        List<ShopSpec> specs = list(query);
        return RPCBaseResponse.success(BeanUtil.copyToList(specs, SpecVo.class));
    }
}
