package edu.travel.commodity.web;

import edu.travel.commodity.entity.ShopProductSpec;
import edu.travel.commodity.service.ShopProductSpecService;
import edu.travel.remote.commodity.ShopProductSpecRemoteController;
import edu.travel.remote.dto.ProductSpecDto;
import edu.travel.remote.dto.ProductSpecInsertShopSpecDto;
import edu.travel.remote.vo.ProductSpecInsertShopSpecVo;
import edu.travel.remote.vo.ProductSpecVo;
import edu.travel.resp.BaseResponse;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static edu.travel.rpc.RPCBaseResponse.success;

/**
 * 商品规格表(shop_product_spec)表控制层
 *
 * @author xxxxx
 */
@RestController
@RequestMapping("/shopProductSpec")
public class ShopProductSpecController extends BaseController<ShopProductSpec> implements ShopProductSpecRemoteController {
    /**
     * 服务对象
     */
    @Autowired
    private ShopProductSpecService shopProductSpecService;

    /**
     * 查询商品详情
     *
     * @return {@link BaseResponse }<{@link List }<{@link ProductSpecVo }>>
     */
    @GetMapping("/getShopSpec")
    public RPCBaseResponse<ProductSpecVo> getShopSpec(ProductSpecDto param) {
        return success(shopProductSpecService.getShopSpec(param));
    }
    /**
     * 通过spec_id，查找多规格值
     */
    @GetMapping("/getShopSpecSortVoList")
    public RPCBaseResponse<List<ProductSpecVo>> getShopSpecSortVoList(String specId) {
        return shopProductSpecService.getShopSpecSortVoList(specId);
    }
    /**
     * 通过product_id，自动填充商品规格
     */
    @PostMapping("/insertOrUpdate")
    public RPCBaseResponse<ProductSpecInsertShopSpecVo> insertOrUpdateProductSpecAndShopSpec(@RequestBody ProductSpecInsertShopSpecDto entity) {
        return shopProductSpecService.insertOrUpdateProductSpecAndShopSpec(entity);
    }

    /**
     * 查找商品规格中间表
     */
    @Override
    @GetMapping("/getFormId")
    public RPCBaseResponse<ProductSpecVo> getFormId(String id) {
        RPCBaseResponse<ShopProductSpec> shopProductSpecRPCBaseResponse = super.getId(id);
        RPCBaseResponse<ProductSpecVo> productSpecVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopProductSpecRPCBaseResponse, productSpecVoRPCBaseResponse);
        return productSpecVoRPCBaseResponse;
    }

    /**
     * 更新商品规格中间表
     */
    @Override
    @PostMapping("/updateTargetFormId")
    public RPCBaseResponse<ProductSpecVo> updateTargetFormId(@RequestBody ProductSpecDto entity) {
        ShopProductSpec shopProductSpec = new ShopProductSpec();
        BeanUtils.copyProperties(entity, shopProductSpec);
        RPCBaseResponse<ShopProductSpec> shopProductSpecRPCBaseResponse = super.updateTargetById(shopProductSpec);
        RPCBaseResponse<ProductSpecVo> productSpecVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopProductSpecRPCBaseResponse, productSpecVoRPCBaseResponse);
        return productSpecVoRPCBaseResponse;
    }

    /**
     * 新增商品规格中间表
     */
    @Override
    @PostMapping("/saveFormTarget")
    public RPCBaseResponse<ProductSpecVo> saveFormTarget(@RequestBody ProductSpecDto entity) {
        ShopProductSpec shopProductSpec = new ShopProductSpec();
        BeanUtils.copyProperties(entity, shopProductSpec);
        RPCBaseResponse<ShopProductSpec> shopProductSpecRPCBaseResponse = super.saveTarget(shopProductSpec);
        RPCBaseResponse<ProductSpecVo> productSpecVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopProductSpecRPCBaseResponse, productSpecVoRPCBaseResponse);
        return productSpecVoRPCBaseResponse;
    }

    /**
     * 删除商品规格中间表
     */
    @Override
    @PostMapping("/deleteTargetFormId")
    public RPCBaseResponse<ProductSpecVo> deleteTargetFormId(@RequestBody List<String> ids) {
        RPCBaseResponse<ShopProductSpec> shopProductSpecRPCBaseResponse = super.deleteTargetById(ids);
        RPCBaseResponse<ProductSpecVo> productSpecVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopProductSpecRPCBaseResponse, productSpecVoRPCBaseResponse);
        return productSpecVoRPCBaseResponse;
    }

    /**
     * 获取所有商品中间表
     * @return
     */
    @Override
    @GetMapping("/getAllForm")
    public RPCBaseResponse<List<ProductSpecVo>> getAllForm() {
        RPCBaseResponse<List<ShopProductSpec>> shopProductSpecRPCBaseResponse = super.listAll();
        RPCBaseResponse<List<ProductSpecVo>> productSpecVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(shopProductSpecRPCBaseResponse, productSpecVoRPCBaseResponse);
        return productSpecVoRPCBaseResponse;
    }
}
